@@ -18,6 +18,10 @@ try:
 except:
     save_path = False
     all_file_name = []
+try:
+    setu_proxy = nonebot.get_driver().config.setu_proxy
+except:
+    setu_proxy = 'px2.rainchan.win'
 
 
 
@@ -53,7 +57,7 @@ async def pic(setu, quality, client):
     setu_author = setu[2]                # 作者
     setu_r18 = setu[3]                   # r18
     setu_tags = setu[4]                  # 标签
-    setu_url = setu[5].replace('i.pixiv.re', 'sex.nyan.xyz')     # 图片url
+    setu_url = setu[5].replace('i.pixiv.re', setu_proxy)     # 图片url
 
     data = (
         "标题:"
@@ -75,7 +79,7 @@ async def pic(setu, quality, client):
         image = Image.open(save_path + "/" + file_name)
     # 如果没有就下载
     else:
-        logger.info("图片本地不存在,正在去sex.nyan.xyz下载")
+        logger.info(f"图片本地不存在,正在去{setu_proxy}下载")
         content = await DownloadPic(setu_url, client)
         
         #  此次fix结束
